==> drone-2.13.0-deps.tar.xz: github.com/drone/drone-ui@v2.8.2+incompatible/CHANGELOG.md <==
# Changelog

## [v2.8.2](https://github.com/drone/drone-ui/tree/v2.8.2) (2022-05-09)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.8.1...v2.8.2)

**Fixed bugs:**

- \(fix\) display durations longer than 24hrs [\#419](https://github.com/drone/drone-ui/pull/419) ([tphoney](https://github.com/tphoney))
- Fix cut-off letter in stage name [\#418](https://github.com/drone/drone-ui/pull/418) ([silverwind](https://github.com/silverwind))

## [v2.8.1](https://github.com/drone/drone-ui/tree/v2.8.1) (2022-04-14)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.8.0...v2.8.1)

**Merged pull requests:**

- actually push the dist... [\#417](https://github.com/drone/drone-ui/pull/417) ([d1wilko](https://github.com/d1wilko))

## [v2.8.0](https://github.com/drone/drone-ui/tree/v2.8.0) (2022-04-14)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.7.1...v2.8.0)

**Implemented enhancements:**

- add registration error message for cloud.drone.io [\#415](https://github.com/drone/drone-ui/pull/415) ([d1wilko](https://github.com/d1wilko))
- add community/support information [\#413](https://github.com/drone/drone-ui/pull/413) ([mrsantons](https://github.com/mrsantons))

**Fixed bugs:**

- \(fix\) add hover text for follow logs button [\#414](https://github.com/drone/drone-ui/pull/414) ([tphoney](https://github.com/tphoney))

**Merged pull requests:**

- \(maint\) release prep for 2.8.0 [\#416](https://github.com/drone/drone-ui/pull/416) ([d1wilko](https://github.com/d1wilko))

## [v2.7.1](https://github.com/drone/drone-ui/tree/v2.7.1) (2022-03-08)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.7.0...v2.7.1)

**Fixed bugs:**

- sort steps based on stepNumber not array index [\#411](https://github.com/drone/drone-ui/pull/411) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- \(maint\) release prep for 2.7.1 [\#412](https://github.com/drone/drone-ui/pull/412) ([d1wilko](https://github.com/d1wilko))

## [v2.7.0](https://github.com/drone/drone-ui/tree/v2.7.0) (2022-03-03)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.6.2...v2.7.0)

**Implemented enhancements:**

- improve error visibility UX [\#409](https://github.com/drone/drone-ui/pull/409) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- remove search text for branches and builds [\#408](https://github.com/drone/drone-ui/pull/408) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.7.0 [\#410](https://github.com/drone/drone-ui/pull/410) ([d1wilko](https://github.com/d1wilko))

## [v2.6.2](https://github.com/drone/drone-ui/tree/v2.6.2) (2022-02-15)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.6.1...v2.6.2)

**Fixed bugs:**

- Persist "Show more" builds when builds are updated [\#406](https://github.com/drone/drone-ui/pull/406) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.6.2 [\#407](https://github.com/drone/drone-ui/pull/407) ([d1wilko](https://github.com/d1wilko))

## [v2.6.1](https://github.com/drone/drone-ui/tree/v2.6.1) (2022-01-27)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.6.0...v2.6.1)

**Merged pull requests:**

- generate go binary [\#405](https://github.com/drone/drone-ui/pull/405) ([d1wilko](https://github.com/d1wilko))

## [v2.6.0](https://github.com/drone/drone-ui/tree/v2.6.0) (2022-01-25)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.5.0...v2.6.0)

**Implemented enhancements:**

- set fixed width on adaptive cards so they display the same length [\#403](https://github.com/drone/drone-ui/pull/403) ([eoinmcafee00](https://github.com/eoinmcafee00))

**Merged pull requests:**

- release prep v2.6.0 [\#404](https://github.com/drone/drone-ui/pull/404) ([eoinmcafee00](https://github.com/eoinmcafee00))

## [v2.5.0](https://github.com/drone/drone-ui/tree/v2.5.0) (2022-01-11)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.4.1...v2.5.0)

**Implemented enhancements:**

- add link around data collection to registration screen [\#397](https://github.com/drone/drone-ui/pull/397) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- allow non-admin user to toggle repo protected status [\#401](https://github.com/drone/drone-ui/pull/401) ([d1wilko](https://github.com/d1wilko))
- fix promotion activity bug [\#400](https://github.com/drone/drone-ui/pull/400) ([d1wilko](https://github.com/d1wilko))
- remove local storage of build tab [\#399](https://github.com/drone/drone-ui/pull/399) ([d1wilko](https://github.com/d1wilko))
- strip trailing slash from url to fix build link bug [\#398](https://github.com/drone/drone-ui/pull/398) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.5.0 [\#402](https://github.com/drone/drone-ui/pull/402) ([d1wilko](https://github.com/d1wilko))

## [v2.4.1](https://github.com/drone/drone-ui/tree/v2.4.1) (2021-12-15)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.4.0...v2.4.1)

**Implemented enhancements:**

- New filter and sort options for repo list [\#395](https://github.com/drone/drone-ui/pull/395) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.4.1 [\#396](https://github.com/drone/drone-ui/pull/396) ([d1wilko](https://github.com/d1wilko))

## [v2.4.0](https://github.com/drone/drone-ui/tree/v2.4.0) (2021-11-04)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.3.1...v2.4.0)

**Implemented enhancements:**

- Feature/dron 101 [\#391](https://github.com/drone/drone-ui/pull/391) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- disable user-select on console line numbers and times [\#390](https://github.com/drone/drone-ui/pull/390) ([saj](https://github.com/saj))

**Merged pull requests:**

- release v2.4.0 [\#392](https://github.com/drone/drone-ui/pull/392) ([d1wilko](https://github.com/d1wilko))

## [v2.3.1](https://github.com/drone/drone-ui/tree/v2.3.1) (2021-10-13)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.3.0...v2.3.1)

**Fixed bugs:**

- show error and console logs for buld steps [\#387](https://github.com/drone/drone-ui/pull/387) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.3.1 [\#388](https://github.com/drone/drone-ui/pull/388) ([d1wilko](https://github.com/d1wilko))

## [v2.3.0](https://github.com/drone/drone-ui/tree/v2.3.0) (2021-09-22)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.2.1...v2.3.0)

**Implemented enhancements:**

- add templates to repo settings [\#385](https://github.com/drone/drone-ui/pull/385) ([d1wilko](https://github.com/d1wilko))
- Feat/dron 129 - Add org secrets page [\#381](https://github.com/drone/drone-ui/pull/381) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- fix graph view crash when runner cannot be found [\#383](https://github.com/drone/drone-ui/pull/383) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.3.0 [\#386](https://github.com/drone/drone-ui/pull/386) ([d1wilko](https://github.com/d1wilko))

## [v2.2.1](https://github.com/drone/drone-ui/tree/v2.2.1) (2021-09-09)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.2.0...v2.2.1)

**Merged pull requests:**

- release v2.2.1 [\#380](https://github.com/drone/drone-ui/pull/380) ([d1wilko](https://github.com/d1wilko))

## [v2.2.0](https://github.com/drone/drone-ui/tree/v2.2.0) (2021-09-09)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.1.0...v2.2.0)

**Implemented enhancements:**

- add runner machine to graph step info drawer [\#376](https://github.com/drone/drone-ui/pull/376) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- kicking off new build manually will push build to build list [\#378](https://github.com/drone/drone-ui/pull/378) ([d1wilko](https://github.com/d1wilko))
- fix builds stream event behaviour [\#377](https://github.com/drone/drone-ui/pull/377) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.2.0 [\#379](https://github.com/drone/drone-ui/pull/379) ([d1wilko](https://github.com/d1wilko))

## [v2.1.0](https://github.com/drone/drone-ui/tree/v2.1.0) (2021-09-01)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.0.1...v2.1.0)

**Implemented enhancements:**

- add new repo setting toggles and generate go binary [\#374](https://github.com/drone/drone-ui/pull/374) ([d1wilko](https://github.com/d1wilko))
- add tooltip to long build step names [\#371](https://github.com/drone/drone-ui/pull/371) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- stop general settings from remounting on each new build [\#373](https://github.com/drone/drone-ui/pull/373) ([d1wilko](https://github.com/d1wilko))
- fix branch link bug [\#372](https://github.com/drone/drone-ui/pull/372) ([rohow](https://github.com/rohow))

**Merged pull requests:**

- release v2.1.0 [\#375](https://github.com/drone/drone-ui/pull/375) ([d1wilko](https://github.com/d1wilko))

## [v2.0.1](https://github.com/drone/drone-ui/tree/v2.0.1) (2021-08-20)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.0.0...v2.0.1)

**Implemented enhancements:**

- new go file [\#366](https://github.com/drone/drone-ui/pull/366) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- fix off centre alt avatar bug [\#368](https://github.com/drone/drone-ui/pull/368) ([d1wilko](https://github.com/d1wilko))
- fix single pending build bug and simplify median build time logic [\#367](https://github.com/drone/drone-ui/pull/367) ([d1wilko](https://github.com/d1wilko))
- show error message for steps and stages [\#365](https://github.com/drone/drone-ui/pull/365) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.0.1 [\#370](https://github.com/drone/drone-ui/pull/370) ([d1wilko](https://github.com/d1wilko))
- Merging drone2 branch into master [\#369](https://github.com/drone/drone-ui/pull/369) ([d1wilko](https://github.com/d1wilko))
- allow ~ in project name [\#361](https://github.com/drone/drone-ui/pull/361) ([muffl0n](https://github.com/muffl0n))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> drone-2.18.0-deps.tar.xz: github.com/drone/drone-ui@v2.11.2+incompatible/CHANGELOG.md <==
# Changelog

## [v2.11.2](https://github.com/drone/drone-ui/tree/v2.11.2) (2023-06-29)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.11.1...v2.11.2)

**Merged pull requests:**

- fix: \[CI-8653\]: convert tmate link logic from expecting an object to expect an array [\#440](https://github.com/drone/drone-ui/pull/440) ([d1wilko](https://github.com/d1wilko))
- fix: button display in deployment form [\#439](https://github.com/drone/drone-ui/pull/439) ([ecmchow](https://github.com/ecmchow))

## [v2.11.1](https://github.com/drone/drone-ui/tree/v2.11.1) (2023-04-20)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.11.0...v2.11.1)

**Fixed bugs:**

- fix regression importing use location [\#437](https://github.com/drone/drone-ui/pull/437) ([d1wilko](https://github.com/d1wilko))
- added missing import + fixed eslint [\#436](https://github.com/drone/drone-ui/pull/436) ([kgwebsites](https://github.com/kgwebsites))

**Merged pull requests:**

- 2.11.1 release prep [\#438](https://github.com/drone/drone-ui/pull/438) ([d1wilko](https://github.com/d1wilko))

## [v2.11.0](https://github.com/drone/drone-ui/tree/v2.11.0) (2023-04-19)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.10.0...v2.11.0)

**Implemented enhancements:**

- Function to prefill promote modal w/ query params [\#434](https://github.com/drone/drone-ui/pull/434) ([kgwebsites](https://github.com/kgwebsites))

**Merged pull requests:**

- 2.11.0 release prep [\#435](https://github.com/drone/drone-ui/pull/435) ([d1wilko](https://github.com/d1wilko))

## [v2.10.0](https://github.com/drone/drone-ui/tree/v2.10.0) (2023-04-17)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.9.1...v2.10.0)

**Implemented enhancements:**

- Prepopulate the new-build-form with query params [\#432](https://github.com/drone/drone-ui/pull/432) ([kgwebsites](https://github.com/kgwebsites))
- feat: add dark theme support [\#430](https://github.com/drone/drone-ui/pull/430) ([ecmchow](https://github.com/ecmchow))

**Merged pull requests:**

- 2.10.0 release prep [\#433](https://github.com/drone/drone-ui/pull/433) ([d1wilko](https://github.com/d1wilko))

## [v2.9.1](https://github.com/drone/drone-ui/tree/v2.9.1) (2023-01-11)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.9.0...v2.9.1)

**Fixed bugs:**

- batch streaming log state updates to improve UI performance [\#428](https://github.com/drone/drone-ui/pull/428) ([d1wilko](https://github.com/d1wilko))
- Spelling [\#427](https://github.com/drone/drone-ui/pull/427) ([jsoref](https://github.com/jsoref))

**Merged pull requests:**

- 2.9.1 release prep [\#429](https://github.com/drone/drone-ui/pull/429) ([d1wilko](https://github.com/d1wilko))

## [v2.9.0](https://github.com/drone/drone-ui/tree/v2.9.0) (2022-10-27)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.8.2...v2.9.0)

**Implemented enhancements:**

- fix low hanging lint issues [\#425](https://github.com/drone/drone-ui/pull/425) ([d1wilko](https://github.com/d1wilko))
- \(maint\) document the release procedure [\#421](https://github.com/drone/drone-ui/pull/421) ([tphoney](https://github.com/tphoney))

**Fixed bugs:**

- bug: \[DRON-433\]: fix new build query logic [\#424](https://github.com/drone/drone-ui/pull/424) ([d1wilko](https://github.com/d1wilko))
- fix deep links bug [\#423](https://github.com/drone/drone-ui/pull/423) ([d1wilko](https://github.com/d1wilko))
- Fix minor grammar error in repository settings [\#422](https://github.com/drone/drone-ui/pull/422) ([kittenswolf](https://github.com/kittenswolf))

**Merged pull requests:**

- v2.9.0 release prep [\#426](https://github.com/drone/drone-ui/pull/426) ([d1wilko](https://github.com/d1wilko))

## [v2.8.2](https://github.com/drone/drone-ui/tree/v2.8.2) (2022-05-09)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.8.1...v2.8.2)

**Fixed bugs:**

- \(fix\) display durations longer than 24hrs [\#419](https://github.com/drone/drone-ui/pull/419) ([tphoney](https://github.com/tphoney))
- Fix cut-off letter in stage name [\#418](https://github.com/drone/drone-ui/pull/418) ([silverwind](https://github.com/silverwind))

**Merged pull requests:**

- Prep v2.8.2 [\#420](https://github.com/drone/drone-ui/pull/420) ([tphoney](https://github.com/tphoney))

## [v2.8.1](https://github.com/drone/drone-ui/tree/v2.8.1) (2022-04-14)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.8.0...v2.8.1)

**Merged pull requests:**

- actually push the dist... [\#417](https://github.com/drone/drone-ui/pull/417) ([d1wilko](https://github.com/d1wilko))

## [v2.8.0](https://github.com/drone/drone-ui/tree/v2.8.0) (2022-04-14)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.7.1...v2.8.0)

**Implemented enhancements:**

- add registration error message for cloud.drone.io [\#415](https://github.com/drone/drone-ui/pull/415) ([d1wilko](https://github.com/d1wilko))
- add community/support information [\#413](https://github.com/drone/drone-ui/pull/413) ([mrsantons](https://github.com/mrsantons))

**Fixed bugs:**

- \(fix\) add hover text for follow logs button [\#414](https://github.com/drone/drone-ui/pull/414) ([tphoney](https://github.com/tphoney))

**Merged pull requests:**

- \(maint\) release prep for 2.8.0 [\#416](https://github.com/drone/drone-ui/pull/416) ([d1wilko](https://github.com/d1wilko))

## [v2.7.1](https://github.com/drone/drone-ui/tree/v2.7.1) (2022-03-08)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.7.0...v2.7.1)

**Fixed bugs:**

- sort steps based on stepNumber not array index [\#411](https://github.com/drone/drone-ui/pull/411) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- \(maint\) release prep for 2.7.1 [\#412](https://github.com/drone/drone-ui/pull/412) ([d1wilko](https://github.com/d1wilko))

## [v2.7.0](https://github.com/drone/drone-ui/tree/v2.7.0) (2022-03-03)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.6.2...v2.7.0)

**Implemented enhancements:**

- improve error visibility UX [\#409](https://github.com/drone/drone-ui/pull/409) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- remove search text for branches and builds [\#408](https://github.com/drone/drone-ui/pull/408) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.7.0 [\#410](https://github.com/drone/drone-ui/pull/410) ([d1wilko](https://github.com/d1wilko))

## [v2.6.2](https://github.com/drone/drone-ui/tree/v2.6.2) (2022-02-15)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.6.1...v2.6.2)

**Fixed bugs:**

- Persist "Show more" builds when builds are updated [\#406](https://github.com/drone/drone-ui/pull/406) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.6.2 [\#407](https://github.com/drone/drone-ui/pull/407) ([d1wilko](https://github.com/d1wilko))

## [v2.6.1](https://github.com/drone/drone-ui/tree/v2.6.1) (2022-01-27)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.6.0...v2.6.1)

**Merged pull requests:**

- generate go binary [\#405](https://github.com/drone/drone-ui/pull/405) ([d1wilko](https://github.com/d1wilko))

## [v2.6.0](https://github.com/drone/drone-ui/tree/v2.6.0) (2022-01-25)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.5.0...v2.6.0)

**Implemented enhancements:**

- set fixed width on adaptive cards so they display the same length [\#403](https://github.com/drone/drone-ui/pull/403) ([eoinmcafee00](https://github.com/eoinmcafee00))

**Merged pull requests:**

- release prep v2.6.0 [\#404](https://github.com/drone/drone-ui/pull/404) ([eoinmcafee00](https://github.com/eoinmcafee00))

## [v2.5.0](https://github.com/drone/drone-ui/tree/v2.5.0) (2022-01-11)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.4.1...v2.5.0)

**Implemented enhancements:**

- add link around data collection to registration screen [\#397](https://github.com/drone/drone-ui/pull/397) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- allow non-admin user to toggle repo protected status [\#401](https://github.com/drone/drone-ui/pull/401) ([d1wilko](https://github.com/d1wilko))
- fix promotion activity bug [\#400](https://github.com/drone/drone-ui/pull/400) ([d1wilko](https://github.com/d1wilko))
- remove local storage of build tab [\#399](https://github.com/drone/drone-ui/pull/399) ([d1wilko](https://github.com/d1wilko))
- strip trailing slash from url to fix build link bug [\#398](https://github.com/drone/drone-ui/pull/398) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.5.0 [\#402](https://github.com/drone/drone-ui/pull/402) ([d1wilko](https://github.com/d1wilko))

## [v2.4.1](https://github.com/drone/drone-ui/tree/v2.4.1) (2021-12-15)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.4.0...v2.4.1)

**Implemented enhancements:**

- New filter and sort options for repo list [\#395](https://github.com/drone/drone-ui/pull/395) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.4.1 [\#396](https://github.com/drone/drone-ui/pull/396) ([d1wilko](https://github.com/d1wilko))

## [v2.4.0](https://github.com/drone/drone-ui/tree/v2.4.0) (2021-11-04)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.3.1...v2.4.0)

**Implemented enhancements:**

- Feature/dron 101 [\#391](https://github.com/drone/drone-ui/pull/391) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- disable user-select on console line numbers and times [\#390](https://github.com/drone/drone-ui/pull/390) ([saj](https://github.com/saj))

**Merged pull requests:**

- release v2.4.0 [\#392](https://github.com/drone/drone-ui/pull/392) ([d1wilko](https://github.com/d1wilko))

## [v2.3.1](https://github.com/drone/drone-ui/tree/v2.3.1) (2021-10-13)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.3.0...v2.3.1)

**Fixed bugs:**

- show error and console logs for build steps [\#387](https://github.com/drone/drone-ui/pull/387) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.3.1 [\#388](https://github.com/drone/drone-ui/pull/388) ([d1wilko](https://github.com/d1wilko))

## [v2.3.0](https://github.com/drone/drone-ui/tree/v2.3.0) (2021-09-22)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.2.1...v2.3.0)

**Implemented enhancements:**

- add templates to repo settings [\#385](https://github.com/drone/drone-ui/pull/385) ([d1wilko](https://github.com/d1wilko))
- Feat/dron 129 - Add org secrets page [\#381](https://github.com/drone/drone-ui/pull/381) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- fix graph view crash when runner cannot be found [\#383](https://github.com/drone/drone-ui/pull/383) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.3.0 [\#386](https://github.com/drone/drone-ui/pull/386) ([d1wilko](https://github.com/d1wilko))

## [v2.2.1](https://github.com/drone/drone-ui/tree/v2.2.1) (2021-09-09)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.2.0...v2.2.1)

**Merged pull requests:**

- release v2.2.1 [\#380](https://github.com/drone/drone-ui/pull/380) ([d1wilko](https://github.com/d1wilko))

## [v2.2.0](https://github.com/drone/drone-ui/tree/v2.2.0) (2021-09-09)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.1.0...v2.2.0)

**Implemented enhancements:**

- add runner machine to graph step info drawer [\#376](https://github.com/drone/drone-ui/pull/376) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- kicking off new build manually will push build to build list [\#378](https://github.com/drone/drone-ui/pull/378) ([d1wilko](https://github.com/d1wilko))
- fix builds stream event behaviour [\#377](https://github.com/drone/drone-ui/pull/377) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.2.0 [\#379](https://github.com/drone/drone-ui/pull/379) ([d1wilko](https://github.com/d1wilko))

## [v2.1.0](https://github.com/drone/drone-ui/tree/v2.1.0) (2021-09-01)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.0.1...v2.1.0)

**Implemented enhancements:**

- add new repo setting toggles and generate go binary [\#374](https://github.com/drone/drone-ui/pull/374) ([d1wilko](https://github.com/d1wilko))
- add tooltip to long build step names [\#371](https://github.com/drone/drone-ui/pull/371) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- stop general settings from remounting on each new build [\#373](https://github.com/drone/drone-ui/pull/373) ([d1wilko](https://github.com/d1wilko))
- fix branch link bug [\#372](https://github.com/drone/drone-ui/pull/372) ([rohow](https://github.com/rohow))

**Merged pull requests:**

- release v2.1.0 [\#375](https://github.com/drone/drone-ui/pull/375) ([d1wilko](https://github.com/d1wilko))

## [v2.0.1](https://github.com/drone/drone-ui/tree/v2.0.1) (2021-08-20)

[Full Changelog](https://github.com/drone/drone-ui/compare/v2.0.0...v2.0.1)

**Implemented enhancements:**

- new go file [\#366](https://github.com/drone/drone-ui/pull/366) ([d1wilko](https://github.com/d1wilko))

**Fixed bugs:**

- fix off centre alt avatar bug [\#368](https://github.com/drone/drone-ui/pull/368) ([d1wilko](https://github.com/d1wilko))
- fix single pending build bug and simplify median build time logic [\#367](https://github.com/drone/drone-ui/pull/367) ([d1wilko](https://github.com/d1wilko))
- show error message for steps and stages [\#365](https://github.com/drone/drone-ui/pull/365) ([d1wilko](https://github.com/d1wilko))

**Merged pull requests:**

- release v2.0.1 [\#370](https://github.com/drone/drone-ui/pull/370) ([d1wilko](https://github.com/d1wilko))
- Merging drone2 branch into master [\#369](https://github.com/drone/drone-ui/pull/369) ([d1wilko](https://github.com/d1wilko))
- allow ~ in project name [\#361](https://github.com/drone/drone-ui/pull/361) ([muffl0n](https://github.com/muffl0n))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
